@@ -19,7 +19,7 @@ sub do_layout {
         $comp->width($cwidth);
         $comp->height($cheight);
         $comp->origin->x($comp->padding->left + $comp->margins->left + $comp->border->width);
-        $comp->origin->x($comp->padding->top + $comp->margins->top + $comp->border->width);
+        $comp->origin->y($comp->padding->top + $comp->margins->top + $comp->border->width);
 
         if($comp->can('do_layout')) {
             $comp->do_layout($comp);
